import LayoutMain from '@/framework/layout/Main'

import Auth from '@/views/system/auth'
import Dasboard from '@/views/dasboard'
import ChangePwd from '@/views/system/pwd/ChangePwd'

/** 报警设置 */
const ProjAlarm = () => import('@/views/alarm/projalarm/index');
const ProjNotice = () => import('@/views/alarm/notice/index');
const StaffSetting = () => import('@/views/alarm/staff/index');

/**与FM相关设置 */
const ProjSop = () => import('@/views/fm/projectsop/index')
const ProjRules = () => import('@/views/fm/projectrule')

/**点位部分 */
import pointConfig from '@/views/point/config_point'
import editDataSouce from '@/views/point/config_point/edit_origin'
import pointSteps from '@/views/point/config_point/steps'

/**项目化配置 */
import collectsetting from "@/views/project_setting/collection_setting/index"

/** 业务空间 */
import spacelist from "@/views/business_space/business_list"

/** 扫楼数据整理 */
import buildAssets from "@/views/data_admin/buildAssets"
import buildLog from "@/views/data_admin/buildLog"
import buildUser from "@/views/data_admin/buildUser"
import buildData from "@/views/data_admin/buildData"
import buildGraphy from "@/views/data_admin/buildGraphy"

/**市场及商务 */
const OwnerManage = () => import('@/views/market/owner/manage')

/**  台账管理 */
import systemLedger from '@/views/ledger/system'
import facilityLedger from '@/views/ledger/facility'
import propertyLedger from '@/views/ledger/property'

export default [
    { path: '/auth', name: 'Auth', component: Auth },
    // 系统相关
    {
        path: '/',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: '/system/changepwd', name: 'ChangePwd', component: ChangePwd }
        ]
    },
    // 报警设置
    {
        path: '/alarmconfig',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'projsetting', name: 'Dasboard', component: ProjAlarm },
            { path: 'projnotice', name: 'Dasboard', component: ProjNotice },
            { path: 'staffsetting', name: 'Dasboard', component: StaffSetting }
        ]
    },
    // 与FM相关设置
    {
        path: '/fm',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'sopsetting', name: 'Dasboard', component: ProjSop },
            { path: 'rulesetting', name: 'Dasboard', component: ProjRules }
        ]
    },
    // 点位表管理
    {
        path: '/point',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'pointConfig', component: pointConfig },
            { path: 'pointsetting', name: 'Dasboard', component: pointConfig },
            { path: 'editDataSouce', name: 'editDataSouce', component: editDataSouce },
            { path: 'pointSteps', name: 'pointSteps', component: pointSteps }
        ]
    },
    //项目化配置
    {
        path: '/proj',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'custominfo', name: 'Dasboard', component: Dasboard },
            { path: 'collectsetting', name: 'collectsetting', component: collectsetting }
        ]
    },
    //台账管理
    {
        path: '/ledger',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'facility', name: 'facilityLedger', component: facilityLedger },
            { path: 'system', name: 'systemLedger', component: systemLedger },
            { path: 'property', name: 'propertyLedger', component: propertyLedger }
        ]
    },
    //业务空间管理    
    {
        path: '/business',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'spacelist', name: 'spacelist', component: spacelist }
        ]
    },
    //竖井管理
    {
        path: '/cenote',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'cenotelist', name: 'Dasboard', component: Dasboard }
        ]
    },
    //租户管理
    {
        path: '/rent',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'rentlist', name: 'Dasboard', component: Dasboard }
        ]
    },
    //扫楼数据管理
    {
        path: '/floor',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'buildData', component: buildData },
            { path: 'data', name: 'buildData', component: buildData },
            { path: 'plan', name: 'buildGraphy', component: buildGraphy },
            { path: 'abnormalprop', name: 'buildAssets', component: buildAssets },
            { path: 'log', name: 'buildLog', component: buildLog },
            { path: 'appuser', name: 'buildUser', component: buildUser },
        ]
    },
    //环境调节
    {
        path: '/environment',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'envlist', name: 'Dasboard', component: Dasboard }
        ]
    },
    //市场及商务
    {
        path: '/market',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'own', name: 'Dasboard', component: OwnerManage }
        ]
    },
    //revit服务器端化的web功能
    {
        path: '/revitservice',
        name: 'LayoutMain',
        component: LayoutMain,
        children: [
            { path: '', name: 'Dasboard', component: Dasboard },
            { path: 'revit', name: 'Dasboard', component: Dasboard }
        ]
    },
]